@@ -1,9 +1,8 @@
 from geezlibs.autobot import *
-from geezlibs.decorator import *
 from geezlibs._wrappers import *
 
 
-from geezlibs import __version__ as grver
+from geezram import __version__ as grver
 from Geez import cmds
 __version__ = "0.0.1"
 bot_version = "0.1.5"
