@@ -1,5 +1,5 @@
 from pyrogram.types import InlineKeyboardButton, WebAppInfo
-from Geez import CMD_HNDLR as cmds
+from Geez import cmds
 class Data:
 
     text_help_menu = (
